@@ -1,10 +1,11 @@
 from themispy.scrapy.items import FileDownloader
-from themispy.scrapy.pipelines import FileDownloaderPipeline
+from themispy.scrapy.pipelines import BlobUploadPipeline, FileDownloaderPipeline
 from themispy.scrapy.readers import read_jsonl
 from themispy.scrapy.spiders import DEFAULT_SETTINGS, run_spider
 
 __all__ = [
     "FileDownloader",
+    "BlobUploadPipeline",
     "FileDownloaderPipeline",
     "read_jsonl",
     "DEFAULT_SETTINGS",
